@@ -51,6 +51,13 @@ else:
     envvar='PACT_BROKER_PASSWORD',
     help='Password for Pact Broker basic authentication. Can also be specified'
          ' via the environment variable PACT_BROKER_PASSWORD')
+@click.option(
+    'header', '--custom-provider-header',
+    envvar='CUSTOM_PROVIDER_HEADER',
+    help='Header to add to provider state set up and '
+         'pact verification requests. '
+         'eg \'Authorization: Basic cGFjdDpwYWN0\'. '
+         'May be specified multiple times.')
 @click.option(
     'timeout', '-t', '--timeout',
     default=30,
@@ -72,8 +79,8 @@ else:
     default=False,
     help='Toggle verbose logging, defaults to False.')
 def main(pacts, base_url, pact_url, pact_urls, states_url,
-         states_setup_url, username, password, timeout, provider_app_version,
-         publish_verification_results, verbose):
+         states_setup_url, username, password, header, timeout,
+         provider_app_version, publish_verification_results, verbose):
     """
     Verify one or more contracts against a provider service.
 
@@ -113,7 +120,8 @@ def main(pacts, base_url, pact_url, pact_urls, states_url,
         '--provider-base-url': base_url,
         '--provider-states-setup-url': states_setup_url,
         '--broker-username': username,
-        '--broker-password': password
+        '--broker-password': password,
+        '--custom-provider-header': header,
     }
     command = [VERIFIER_PATH]
     command.extend(all_pact_urls)
@@ -140,6 +148,7 @@ def main(pacts, base_url, pact_url, pact_urls, states_url,
                          stderr=subprocess.STDOUT, universal_newlines=True)
 
     sanitize_logs(p, verbose)
+    p.wait()
     sys.exit(p.returncode)
 
 
